[evolution-ews] Bug #712255 - Name all the timeouts added with g_timeout_add()



commit 794a2165fc3fb60fb77b45c1685b54a7c2af888d
Author: Fabiano Fidêncio <fidencio redhat com>
Date:   Wed Nov 13 23:11:38 2013 +0100

    Bug #712255 - Name all the timeouts added with g_timeout_add()

 src/calendar/e-cal-backend-ews.c          |    2 +-
 src/camel/camel-ews-store.c               |    4 ++--
 src/configuration/e-ews-ooo-notificator.c |    6 +++---
 src/configuration/e-ews-search-user.c     |    2 +-
 src/utils/e-sqlite3-vfs.c                 |    2 +-
 5 files changed, 8 insertions(+), 8 deletions(-)
---
diff --git a/src/calendar/e-cal-backend-ews.c b/src/calendar/e-cal-backend-ews.c
index 8dc2547..d21f410 100644
--- a/src/calendar/e-cal-backend-ews.c
+++ b/src/calendar/e-cal-backend-ews.c
@@ -4187,7 +4187,7 @@ ews_cal_start_refreshing (ECalBackendEws *cbews)
            e_backend_get_online (E_BACKEND (cbews)) &&
            priv->cnc) {
                ews_start_sync (cbews);
-               priv->refresh_timeout = g_timeout_add_seconds (
+               priv->refresh_timeout = e_named_timeout_add_seconds (
                        REFRESH_INTERVAL, (GSourceFunc) ews_start_sync, cbews);
        }
 
diff --git a/src/camel/camel-ews-store.c b/src/camel/camel-ews-store.c
index f534d2e..9a4a384 100644
--- a/src/camel/camel-ews-store.c
+++ b/src/camel/camel-ews-store.c
@@ -835,7 +835,7 @@ schedule_folder_update (CamelEwsStore *ews_store,
 
        settings = camel_service_ref_settings (CAMEL_SERVICE (ews_store));
 
-       ews_store->priv->update_folder_id = g_timeout_add_seconds_full (
+       ews_store->priv->update_folder_id = e_named_timeout_add_seconds_full (
                                                                G_PRIORITY_LOW,
                                                                1,
                                                                folder_update_cb,
@@ -896,7 +896,7 @@ schedule_folder_list_update (CamelEwsStore *ews_store)
 
        settings = camel_service_ref_settings (CAMEL_SERVICE (ews_store));
 
-       ews_store->priv->update_folder_list_id = g_timeout_add_seconds_full (
+       ews_store->priv->update_folder_list_id = e_named_timeout_add_seconds_full (
                                                                G_PRIORITY_LOW,
                                                                1,
                                                                folder_list_update_cb,
diff --git a/src/configuration/e-ews-search-user.c b/src/configuration/e-ews-search-user.c
index 9597eef..1eff8ed 100644
--- a/src/configuration/e-ews-search-user.c
+++ b/src/configuration/e-ews-search-user.c
@@ -363,7 +363,7 @@ search_term_changed_cb (GtkEntry *entry,
                sid->dialog = dialog;
 
                gtk_label_set_text (GTK_LABEL (pgu->info_label), _("Searching..."));
-               pgu->schedule_search_id = g_timeout_add (333, schedule_search_cb, sid);
+               pgu->schedule_search_id = e_named_timeout_add (333, schedule_search_cb, sid);
        }
 }
 
diff --git a/src/utils/e-sqlite3-vfs.c b/src/utils/e-sqlite3-vfs.c
index cec0b75..2f6d28c 100644
--- a/src/utils/e-sqlite3-vfs.c
+++ b/src/utils/e-sqlite3-vfs.c
@@ -245,7 +245,7 @@ e_sqlite3_file_xSync (sqlite3_file *pFile,
                g_source_remove (cFile->timeout_id);
 
        /* Wait SYNC_TIMEOUT_SECONDS before we actually sync. */
-       cFile->timeout_id = g_timeout_add_seconds (
+       cFile->timeout_id = e_named_timeout_add_seconds (
                SYNC_TIMEOUT_SECONDS, (GSourceFunc)
                sync_push_request_timeout, cFile);
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/configuration/e-ews-ooo-notificator.c b/src/configuration/e-ews-ooo-notificator.c
index 1c76d86..07ce754 100644
--- a/src/configuration/e-ews-ooo-notificator.c
+++ b/src/configuration/e-ews-ooo-notificator.c
@@ -194,7 +194,7 @@ e_ews_ooo_notificator_show_notification (EEwsOooNotificator *extension,
        e_alert_sink_submit_alert (E_ALERT_SINK (shell_content), alert);
 
        /* If the user doesn't cancel the notify, it will be hide automatically in 5 minutes */
-       data->timeout_id = g_timeout_add_seconds_full (
+       data->timeout_id = e_named_timeout_add_seconds_full (
                        G_PRIORITY_DEFAULT, 300,
                        e_ews_ooo_notificator_hide_notification_by_timeout_cb,
                        data, e_ews_ooo_notificator_dispatcher_data_free);
@@ -252,14 +252,14 @@ e_ews_ooo_notificator_service_removed (gpointer user_data)
 /*
  * GTK+ UI calls cannot be done in a dedicated thread.
  * So, let's ensure that our functions (that do something in the UI) will run
  * in the main thread, calling them through g_timeout_add_full().
  */
 static void
 e_ews_ooo_notificator_dispatcher (EEwsOooNotificatorDispatcherData *data,
                                  EEwsOooNotificationDispatcherFunction function,
                                  GDestroyNotify destroy_data)
 {
-       g_timeout_add_full (G_PRIORITY_DEFAULT, 1, function, data, destroy_data);
+       e_named_timeout_add_full (G_PRIORITY_DEFAULT, 1, function, data, destroy_data);
 }
 
 static void
@@ -252,14 +252,14 @@ e_ews_ooo_notificator_service_removed (gpointer user_data)
  * GTK+ UI calls cannot be done in a dedicated thread.
  * So, let's ensure that our functions (that do something in the UI) will run
- * in the main thread, calling them through g_timeout_add_full().
+ * in the main thread, calling them through e_named_timeout_add_full().
  */
 static void